@@ -5,7 +5,8 @@ use all4art_authservice_domain::{public_key::{PublicKey, self}, user::User, fact
 
 #[async_trait]
 pub trait UserRepository {
-    async fn retrieve_user(&self, public_key: &PublicKey) -> Result<Arc<dyn User>, std::io::Error>;
+    async fn retrieve_user(&self, public_key: &PublicKey) 
+    -> Result<Arc<dyn User + Send + Sync>, std::io::Error>;
     async fn create_user(&self, user: Arc<dyn User + Send + Sync>) -> Result<(), std::io::Error>;
 }
 
@@ -17,7 +18,7 @@ pub struct UserRepositoryImpl {
 
 #[async_trait]
 impl UserRepository for UserRepositoryImpl { 
-    async fn retrieve_user(&self, public_key: &PublicKey) -> Result<Arc<dyn User>, std::io::Error> { 
+    async fn retrieve_user(&self, public_key: &PublicKey) -> Result<Arc<dyn User + Send + Sync>, std::io::Error> { 
         let public_key = PublicKey::new(String::from("public_key"));
         let hashed_password = self.hashed_password_factory.create()?;
         let user = self.user_factory.create(public_key, hashed_password)?;
